# The default iP address of MC is 90.0.0.1
# This routine get the vars by searching the nodeID and accessing it by nodeID
from opcua import Client
import time


def browse_node(node, var_name):
    for child in node.get_children():
        if child.get_display_name().Text == var_name:
            return child
        else:
            result = browse_node(child, var_name)
            if result:
                return result
    return None


def main(server_url, cli):
    client = cli(server_url)
    try:
        client.connect()
        print("Client connected to OPC UA Server")

        objects = client.get_objects_node()
        var_A1 = "A1_CYCLE"
        var_A2 = "A2_CYCLE"
        variable_node_1 = browse_node(objects, var_A1)
        variable_node_2 = browse_node(objects, var_A2)

        if variable_node_1 and variable_node_2:
            print(f'Found variable nodes: {variable_node_1} and {variable_node_2}')
            while True:
                value_1 = variable_node_1.get_value()
                value_2 = variable_node_2.get_value()
                print(f'Value of {var_A1} is: {value_1}, {var_A2} is: {value_2}')
                time.sleep(1)  # Query once per second
        else:
            print(f"Variable {var_A1} and {var_A2} can not be founded.")

    except Exception as e:
        print(f'Error occurred: {e}')

    finally:
        client.disconnect()
        print("Client disconnected from OPC UA Server")


if __name__ == "__main__":
    server_url = "opc.tcp://90.0.0.1:4840"
    cli = Client
    main(server_url, cli)
